
# MSP430i20xx Sigma-Delta ADC Demo

----------

This GUI communicates with a MSP430i2041 MCU to display real-time data from the integrated Sigma-Delta ADCs and allows you to configure the gain and preload settings for each ADC channel. The MSP430i2041 is used in this demo, but other MSP430i20xx MCUs will also work.

This demo uses the [MSP-TS430RHB32A target development board](https://www.ti.com/tool/MSP-TS430RHB32A). Two different signals from sensors or a function generator can be applied to the MSP430i2041's A0.0+/- and A1.0+/- ADC channels. For embedded metering applications, the [EVM430-i2040S](https://www.ti.com/tool/EVM430-I2040S) can also be used with this GUI to view ADC data from the on-board voltage and current sensors.

> **NOTE**
> 
> - The isolated RS-232 serial port on the [EVM430-i2040S](https://www.ti.com/tool/EVM430-I2040S) may not reliably support the high baud rate required by this demo. A TTL-to-USB serial converter cable will be required, but isolation may be necessary if high voltage is connected to the EVM430-i2040S.

# Requirements

----------

## Target Hardware

 - Either [MSP-TS430RHB32A target development board](https://www.ti.com/tool/MSP-TS430RHB32A) (other sensing applications) or [EVM430-i2040S](https://www.ti.com/tool/EVM430-I2040S) (embedded metering applications) can be used
 - [MSP-FET](https://www.ti.com/tool/MSP-FET) for programming the MCU and debugging the firmware
 - TTL-to-USB serial converter for enabling high-speed UART communication between the MCU and the GUI (e.g. TTL-232R-3V3)
 - Function generator (recommended for target board only)
 - Logic analyzer (optional)
 - Jumper wires (optional)

## Target Software

 - The [demo firmware](https://dev.ti.com/tirex/) can be programmed onto the MSP430i2041 (only) by selecting **File** > **Program Device...** in this GUI
 - All MSP430i20xx MCUs can be programmed using the `msp430i20xx_sigma-delta_adc_demo_mpack` project in [Code Composer Studio (CCS)](https://www.ti.com/tool/CCSTUDIO-MSP)

# Instructions

----------

## Setup

1. Install the drivers for the TTL-to-USB serial converter (see the manufacturer's website).
2. Configure the function generator.
3. Open this [GUI Composer demo](https://dev.ti.com/gallery/info/TIMSPGC/MSP430i20xx_Sigma-Delta_ADC_Demo/) in a browser.

## Connections

 1. Connect the MSP-FET to your PC and the [MSP-TS430RHB32A target development board](https://www.ti.com/tool/MSP-TS430RHB32A).
 2. Program the MCU with the demo firmware if you haven't done so already.
 3. Unplug the MSP-FET from your PC and plug it back in to power cycle the MCU.
	 1.  P1.4 (D1) ===> Status LED turns on indicating device has powered up
 4. Connect the TTL-to-USB serial converter to the target development board and your PC.
	 1. P1.2/UCA0RXD <=== serial converter's TX wire (data from PC)
	 2. P1.3/UCA0TXD ===> serial converter's RX wire (data to PC)
	 3. GND <===> serial converter's GND wire
 5. If not connected automatically, click on the link icon at the bottom
    left corner and make sure the serial connection has been established
    at 921200 baud rate. (GUI status bar indicates "waiting for data...")
 6. Connect two signals from your sensors or a function generator to the ADC inputs.
	 1. A0.0+ <=== Signal 1+
	 2. A0.0- <=== Signal 1-
	 3. A1.0+ <=== Signal 2+
	 4. A1.0- <=== Signal 2-
 7. View the ADC data in the GUI.
 8. Adjust the gain and preload for each ADC channel to observe how the signals are amplified and delayed with respect to each other.
	 1. P1.4 (D1) ===> Status LED toggles when commands from the GUI are received and processed
 9. If the graph doesn't show your signal properly (e.g. slow frequency, low amplitude signals), you can edit the GUI's scalar graph properties in GUI Composer to adjust the x-axis (buffer length) or y-axis (series min and max values). To learn more, refer to the [GUI Composer User's Guide](https://dev.ti.com/gc/designer/help/GC_UserGuide_v2/index.html).

> **NOTE**
>
> - Make sure the COM port for the serial converter is selected, not the MSP-FET's.
> - Be careful not to exceed the ADC's full-scale range (FSR) for each gain setting. For more details, please refer to the MSP430i2041 [datasheet](https://www.ti.com/lit/gpn/msp430i2041) and [user's guide](https://www.ti.com/lit/pdf/slau335).
> - The MSP430i2041 communicates with the GUI using MessagePack-formatted strings to transmit the ADC data and settings. For more details, please refer to the [GUI Composer User's Guide](https://dev.ti.com/gc/designer/help/GC_UserGuide_v2/targetprog.html?highlight=message#usb-uart).
> - The browser's Developer Console can be used to view the MessagePack commands being sent to and from the MSP430i2041. A logic analyzer can also be used.